==> openGion7.0.1.4_dev.zip: uap/webapps/ge/db/DERBY/sql/install/01_TABLE/GE18S.sql <==
/****************************************************************************/
/* GE18 ( 位置情報管理ﾃｰﾌﾞﾙ )                                               */
/*                                                                          */
/* Created : 2018/09/28 16:03:46                                            */
/****************************************************************************/

CREATE TABLE GE18 (
   SYSTEM_ID    VARCHAR (   10 )                    NOT NULL                                                                                                        /*  10 ｼｽﾃﾑID       */
 , LOC_GRP      VARCHAR (   30 )                    NOT NULL                                                                                                        /*  20 位置ｸﾞﾙｰﾌﾟ   */
 , LOC_KEY      VARCHAR (   30 )                    NOT NULL                                                                                                        /*  30 固有ID       */
 , LOC_COL      BIGINT                  DEFAULT 0   NOT NULL                                                                                                        /*  40 列位置       */
 , LOC_ROW      BIGINT                  DEFAULT 0   NOT NULL                                                                                                        /*  50 行位置       */
 , NAME_JA      VARCHAR (  200 )                                                                                                                                    /*  60 名称         */
 , LABEL_NAME   VARCHAR (   60 )                                                                                                                                    /*  70 表示名称     */
 , BIKO         VARCHAR ( 2000 )                                                                                                                                    /*  80 備考         */
 , ICON         VARCHAR (  200 )                                                                                                                                    /*  90 ｱｲｺﾝ         */
 , R_KEY1       VARCHAR (   30 )                                                                                                                                    /* 100 連結ｷｰ1      */
 , R_KEY2       VARCHAR (   30 )                                                                                                                                    /* 110 連結ｷｰ2      */
 , R_KEY3       VARCHAR (   30 )                                                                                                                                    /* 120 連結ｷｰ3      */
 , UNIQ         BIGINT                              NOT NULL     generated always as identity (start with 1, increment by 1),constraint GE18 primary key(UNIQ)      /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (    1 )        DEFAULT '1' NOT NULL                                                                                                        /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (   14 )                                                                                                                                    /* 820 登録日時     */
 , PGSET        VARCHAR (   10 )                                                                                                                                    /* 830 作成PG       */
 , PGPSET       VARCHAR (   10 )                                                                                                                                    /* 840 作成親PG     */
 , USRSET       VARCHAR (   10 )                                                                                                                                    /* 850 作成者       */
 , DYUPD        VARCHAR (   14 )                                                                                                                                    /* 860 更新日時     */
 , PGUPD        VARCHAR (   10 )                                                                                                                                    /* 870 更新PG       */
 , PGPUPD       VARCHAR (   10 )                                                                                                                                    /* 880 更新親PG     */
 , USRUPD       VARCHAR (   10 )                                                                                                                                    /* 890 更新者       */
);

==> openGion7.3.1.3_dev.zip: uap/webapps/ge/db/DERBY/sql/install/01_TABLE/GE18S.sql <==
/****************************************************************************/
/* GE18 ( 位置情報管理ﾃｰﾌﾞﾙ )                                               */
/*                                                                          */
/* Created : 2020/12/16 08:14:26                                            */
/****************************************************************************/

CREATE TABLE GE18 (
   SYSTEM_ID    VARCHAR (   10 )                    NOT NULL                                                                                                        /*  10 ｼｽﾃﾑID       */
 , LOC_GRP      VARCHAR (   30 )                    NOT NULL                                                                                                        /*  20 位置ｸﾞﾙｰﾌﾟ   */
 , LOC_KEY      VARCHAR (   30 )                    NOT NULL                                                                                                        /*  30 固有ID       */
 , LOC_COL      BIGINT                  DEFAULT 0   NOT NULL                                                                                                        /*  40 列位置       */
 , LOC_ROW      BIGINT                  DEFAULT 0   NOT NULL                                                                                                        /*  50 行位置       */
 , NAME_JA      VARCHAR (  200 )                                                                                                                                    /*  60 名称         */
 , LABEL_NAME   VARCHAR (   60 )                                                                                                                                    /*  70 表示名称     */
 , BIKO         VARCHAR ( 2000 )                                                                                                                                    /*  80 備考         */
 , ICON         VARCHAR (  200 )                                                                                                                                    /*  90 ｱｲｺﾝ         */
 , R_KEY1       VARCHAR (   30 )                                                                                                                                    /* 100 連結ｷｰ1      */
 , R_KEY2       VARCHAR (   30 )                                                                                                                                    /* 110 連結ｷｰ2      */
 , R_KEY3       VARCHAR (   30 )                                                                                                                                    /* 120 連結ｷｰ3      */
 , UNIQ         BIGINT                              NOT NULL     generated always as identity (start with 1, increment by 1),constraint GE18 primary key(UNIQ)      /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (    1 )        DEFAULT '1' NOT NULL                                                                                                        /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (   14 )                                                                                                                                    /* 820 作成日時     */
 , PGSET        VARCHAR (   10 )                                                                                                                                    /* 830 作成PG       */
 , PGPSET       VARCHAR (   10 )                                                                                                                                    /* 840 作成親PG     */
 , USRSET       VARCHAR (   10 )                                                                                                                                    /* 850 作成者       */
 , DYUPD        VARCHAR (   14 )                                                                                                                                    /* 860 更新日時     */
 , PGUPD        VARCHAR (   10 )                                                                                                                                    /* 870 更新PG       */
 , PGPUPD       VARCHAR (   10 )                                                                                                                                    /* 880 更新親PG     */
 , USRUPD       VARCHAR (   10 )                                                                                                                                    /* 890 更新者       */
);
